package com.xingxi.master.tag.mapper;

import com.xingxi.master.tag.domain.Tag;

import java.util.List;

/**
 * 标签Mapper接口
 *
 * @author xingxi
 * @date 2025-03-06
 */
public interface TagMapper {
    /**
     * 查询标签
     *
     * @param tagId 标签主键
     * @return 标签
     */
    Tag selectTagByTagId(Long tagId);

    /**
     * 查询标签列表
     *
     * @param tag 标签
     * @return 标签集合
     */
    List<Tag> selectTagList(Tag tag);

    /**
     * 新增标签
     *
     * @param tag 标签
     * @return 结果
     */
    int insertTag(Tag tag);

    /**
     * 批量新增标签
     *
     * @param tagList 标签
     * @return 结果
     */
    int batchInsertTag(List<Tag> tagList);

    /**
     * 修改标签
     *
     * @param tag 标签
     * @return 结果
     */
    int updateTag(Tag tag);

    /**
     * 删除标签
     *
     * @param tagId 标签主键
     * @return 结果
     */
    int deleteTagByTagId(Long tagId);

    /**
     * 批量删除标签
     *
     * @param tagIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteTagByTagIds(String[] tagIds);


    /**
     * 逻辑删除标签
     *
     * @param tagId 标签主键
     * @return 结果
     */
    int logicDeleteTagByTagId(Long tagId);

    /**
     * 逻辑批量删除标签
     *
     * @param tagIds 需要删除的数据主键集合
     * @return 结果
     */
    int logicDeleteTagByTagIds(String[] tagIds);

    /**
     * 逻辑批量删除标签
     *
     * @param tag 标签
     * @return 结果
     */
    int logicDeleteTagByCondition(Tag tag);

}
